@@ -1,35 +1,26 @@
-#  gnuhealth_csv_lab_interface.py
-#  
-#  Copyright 2017 Luis Falcon <falcon@gnuhealth.org>
-#  Copyright 2011-2022 GNU Solidario <health@gnusolidario.org>
-#  
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#  
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#  
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-#  MA 02110-1301, USA.
-#  
-#  
+#!/usr/bin/env python 
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
 
-# Check the README file for documentation on how to use this program
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                    health_csv_lab_interface.py                        #
+#         Sample script to upload lab orders from a CSV file            #
+#########################################################################
 
 from proteus import config, Model
 import csv
 import sys
 
-dbname = 'health37dev'
+dbname = 'health40'
 user = 'admin'
 password = 'gnusolidario'
-hostname = 'localhost'
+hostname = 'federation.gnuhealth.org'
 port = '8000'
 
 health_server = \
