@@ -1,30 +1,21 @@
-##############################################################################
-#
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#    The GNU Health HMIS component is part of the GNU Health project
-#    www.gnuhealth.org
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+#!/usr/bin/env python
+
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
+
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                     HEALTH LAB package                                #
+#                health_lab.py: main module                             #
+#########################################################################
 from datetime import datetime
 from trytond.model import ModelView, ModelSQL, fields, Unique
-from trytond.pool import Pool
+from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval, Not, Bool
 from trytond.modules.health.core import get_health_professional
 
@@ -34,8 +25,7 @@ __all__ = [
     'GnuHealthPatientLabTest', 'PatientHealthCondition']
 
 
-class PatientData(ModelSQL, ModelView):
-    'Patient lab tests'
+class PatientData(metaclass=PoolMeta):
     __name__ = 'gnuhealth.patient'
 
     lab_test_ids = fields.One2Many(
@@ -355,8 +345,7 @@ class GnuHealthPatientLabTest(ModelSQL, ModelView):
             tests, default=default)
 
 
-class PatientHealthCondition(ModelSQL, ModelView):
-    'Patient Conditions History'
+class PatientHealthCondition(metaclass=PoolMeta):
     __name__ = 'gnuhealth.patient.disease'
 
     # Adds lab confirmed and the link to the test to the
