@@ -1,27 +1,19 @@
-##############################################################################
+# SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
+# SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
 #
-#    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
-#
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# SPDX-License-Identifier: GPL-3.0-or-later
+#########################################################################
+#   Hospital Management Information System (HMIS) component of the      #
+#                       GNU Health project                              #
+#                   https://www.gnuhealth.org                           #
+#########################################################################
+#                        HEALTH PEDIATRICS package                      #
+#                   health_pediatrics.py: main module                   #
+#########################################################################
+
 from trytond.model import ModelView, ModelSQL, fields, Unique
 from trytond.transaction import Transaction
-from trytond.pool import Pool
+from trytond.pool import Pool, PoolMeta
 from datetime import datetime
 from trytond.pyson import Eval, Not, Equal
 from trytond.modules.health.core import get_health_professional
@@ -349,16 +341,14 @@ class NeonatalApgar(ModelSQL, ModelView):
 
 
 # Deprecated in 3.0 - Use the main patient form
-class NeonatalMedication(ModelSQL, ModelView):
-    'Neonatal Medication. Inherit and Add field to Medication model'
+class NeonatalMedication(metaclass=PoolMeta):
     __name__ = 'gnuhealth.patient.medication'
 
     newborn_id = fields.Many2One('gnuhealth.newborn', 'Newborn ID')
 
 
 # Deprecated in 3.0  - Use main patient form
-class NeonatalCongenitalDiseases(ModelSQL, ModelView):
-    'Congenital Diseases. Inherit Disease object for use in neonatology'
+class NeonatalCongenitalDiseases(metaclass=PoolMeta):
     __name__ = 'gnuhealth.patient.disease'
 
     newborn_id = fields.Many2One('gnuhealth.newborn', 'Newborn ID')
